@@ -124,6 +124,10 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         }
         RequestBuilder builder = RequestBuilder.post(createUrl());
         builder.setCharset(Charset.forName("UTF-8"));
+        String forwardedFor = credentials.getForwardedFor();
+        if (!StringUtils.isEmpty(forwardedFor)) {
+            builder.addHeader(RequestUtil.HEADER_X_FORWARDED_FOR, forwardedFor);
+        }
         String userAgent = credentials.getUserAgent();
         if (userAgent != null) {
             builder.addHeader(RequestUtil.HEADER_USER_AGENT, userAgent);
