@@ -65,7 +65,9 @@ import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteMailsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.EnvelopesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.GetJsLobConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetMailConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.ManifestsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.MoveMailsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.PnsSubscribeConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.PnsUnsubscribeConnector;
@@ -103,12 +105,16 @@ public interface ConnectorFactory {
 
     ExamineMultipleFoldersConnector getExamineMultipleFoldersConnector(SessionData sessionData, List<Folder> folderIds);
 
+    GetJsLobConnector getGetJsLobConnector(SessionData sessionData, String name);
+
     GetMailConnector getGetMailConnector(SessionData sessionData, String folderId, String mailId);
 
     LoginConnector getLoginConnector(LoginCredentials credentials);
 
     LogoutConnector getLogoutConnector(SessionData sessionData);
 
+    ManifestsConnector getManifestsConnector();
+
     MoveMailsConnector getMoveMailsConnector(SessionData sessionData, String folderId, List<String> mailIds, String targetFolderId);
 
     PnsSubscribeConnector getPnsSubscribeConnector(SessionData sessionData, String transport, String token, List<String> tokens);
