@@ -50,6 +50,10 @@
 package com.openexchange.mobile.api.facade.connectors.impl;
 
 import java.nio.charset.Charset;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+import java.util.Map;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.connectors.BaseConnector;
@@ -98,7 +102,7 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         addSessionData(builder);
         builder.addParameter("action", "allVisible");
         builder.addParameter("content_type", "mail");
-        builder.addParameter("columns", "1,20,300,302,316");
+        builder.addParameter("columns", "1,20,300,302,316,306");
         if (!StringUtils.isEmpty(rootFolderId)) {
             builder.addParameter("root", rootFolderId);
         }
@@ -108,6 +112,23 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         return builder.build();
     }
 
+    public static List<Folder> map(Object[][] data, String archiveFolderId, boolean includeNonPrivateFolders) {
+        if (data == null) {
+            return Collections.emptyList();
+        }
+        List<Folder> folders = new ArrayList<>();
+        for (Object[] folderData : data) {
+            Folder folder = AllFoldersConnector.map(folderData);
+            if (folder != null && isMailFolder(folder, includeNonPrivateFolders)) {
+                if (folder.getId().equals(archiveFolderId)) {
+                    folder = folder.withType(Folder.Type.ARCHIVE);
+                }
+                folders.add(folder);
+            }
+        }
+        return folders;
+    }
+
     public static Folder map(Object[] data) {
         String folderId = (String) data[0];
         String parentFolderId = (String) data[1];
@@ -115,7 +136,8 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         Integer folderType = (Integer) data[3];
         Integer standardFolderType = (Integer) data[4];
         Folder.Type type = lookupType(standardFolderType, folderType);
-        return new Folder(folderId, parentFolderId, name, type);
+        boolean isUserVisible = isUserVisible(data[5]);
+        return isUserVisible ? new Folder(folderId, parentFolderId, name, type) : null;
     }
 
     private static Folder.Type lookupType(Integer standardFolderType , Integer folderType) {
@@ -165,4 +187,27 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         }
     }
 
+    private static boolean isMailFolder(Folder folder, boolean includeNonPrivateFolders) {
+        boolean isSubFolder = folder.getParentId() != null && folder.getId().startsWith(folder.getParentId());
+        return isSubFolder && (includeNonPrivateFolders || (!Folder.Type.PUBLIC.equals(folder.getType()) && !Folder.Type.SHARED.equals(folder.getType())));
+    }
+
+    private static boolean isUserVisible(Object data) {
+        if (data instanceof List) {
+            List<?> permissionList = (List<?>) data;
+            if (permissionList.size() == 1) {
+                Object obj = permissionList.get(0);
+                if (obj instanceof Map) {
+                    @SuppressWarnings("unchecked")
+                    Map<String, Object> permissions = (Map<String, Object>) obj;
+                    Object bits = permissions.get("bits");
+                    if (bits instanceof Integer) {
+                        return ((Integer) bits).intValue() > 64;
+                    }
+                }
+            }
+        }
+        return false;
+    }
+
 }
