@@ -145,7 +145,7 @@ public class AuthenticationEndpoint {
     }
 
     private Response buildResponse(SessionData sessionData) {
-        AuthenticationResponseBody responseBody = new AuthenticationResponseBody(sessionData.getSession());
+        AuthenticationResponseBody responseBody = new AuthenticationResponseBody(sessionData);
         String rawResponseBody = JacksonUtil.toString(responseBody);
         Response.ResponseBuilder builder = Response.ok(rawResponseBody);
         CookieUtil.addToResponse(builder, sessionData.getCookies());
